<h1>Entity to code py</h1>


Version | 0.0.1  
--- | --- 
Stable | yes 


<h2>New feats</h2>
<h3>0.0.1 </h3>
<p><b>First with add_one()</b></p>

<h2>Usage</h2>
<h3>1) Installation</h3>

    pip install entitytocodepy_official==x.y.z
    pip install entitytocodepy_official==0.0.1


<h3>2) Importing to your python script</h3>

    from entitytocodepy import main

<h3>3) Using, here's a sample function</h3>

    main.add_one(1)

Output

    2

<h2>Methods</h2>
<h3>add_one (0.0.1 +)</h3>

Import

    from entitytocodepy import main
Use

    main.add_one(1)
